<div class="outline">
New filter. Experiment at your own risk.
<form action="{{ .SaveAction }}" method="POST">
<input type="hidden" name="CSRF" value="{{ .SaveCSRF }}">
<input type="hidden" name="pg" value="filters">
<p><label for=name>name:</label><br>
<input tabindex=1 type="text" name="name" autocomplete=off>
<p><label for=notes>notes:</label><br>
<input tabindex=1 type="text" name="notes" autocomplete=off>

<p><label for=type>type: (post or comment)</label><br>
<input tabindex=1 type="text" name="type" autocomplete=off>
<p><label for=match>match:</label><br>
<input tabindex=1 type="text" name="match" autocomplete=off>
<p><label for=action>action:</label><br>
<input tabindex=1 type="text" name="action" autocomplete=off>

<p><button>filter</button>
</form>
</div>
